@@ -1,6 +1,7 @@
 """Image-related visualization.
 """
 
+import matplotlib.pyplot as plt
 import numpy as np
 from PIL import Image
 
@@ -152,3 +153,30 @@ def create_mosaic(tensor):
     img.show()
 
     logger.debug('Mosaic created.')
+
+
+def create_rgb_mosaic(tensor, n_samples=1):
+    """Creates a squared mosaic for RGB images.
+
+    Args:
+        tensor (Tensor): An input tensor to have its mosaic created.
+        n_samples (int): The amount of samples to be plotted (width or height).
+
+    """
+
+    # Permutes the tensor and transforms into numpy-based array
+    array = tensor.detach().permute(0, 2, 3, 1).numpy()
+
+    # plot images from the dataset
+    for i in range(n_samples * n_samples):
+        # Creates the subplots
+        plt.subplot(n_samples, n_samples, 1 + i)
+
+        # Removes the axis
+        plt.axis('off')
+
+        # Plots the raw data
+        plt.imshow(array[i])
+
+    # Shows the plot
+    plt.show()
